/*----------------------------------------------------------------
 * boot.c -- function to boot the game
 *----------------------------------------------------------------
 *  This function is called by either version of the startup code
 *  to boot the game.  The situation is now pretty much what it
 *  would be in a pure DOS environment at the start of the `main'
 *  function.
 */

#include <allegro.h>

#include "boot.h"
#include "criterr.h"
#include "variable.h"
#include "init.h"
#include "game.h"
#include "animator.h"
#include "time.h"
#include "comix.h"
#include "sound.h"
#include "menu.h"



BITMAP *na_nic;	// kvuli chybe videokarty?

/* boot:
 *  This is much like your normal `main' function.
 */
void boot (int argc, char *argv[])
{
	FILE *fsetup;
	int gmode, rgfx;
	int gdepth;

//SMAZAT ANIM_OBJECT_STRUCTURE *test_object;
//SMAZAT MODEL_STRUCTURE *test_model;


#ifdef DEBUG_VERSION
    debugfile = fopen( "debug.txt", "w");
#endif


    srand((unsigned)time( NULL ));

	/* Initialise Allegro and its components */
	allegro_init();
    install_keyboard();
    //TIMER install_timer();    // instalace timeru

    install_mouse();

	fsetup = fopen("setup.cfg", "r");
	fscanf(fsetup,"GFX_MODE %d\n", &gmode);
	fscanf(fsetup,"GFX_COLOR %d\n", &gdepth);
	fscanf(fsetup,"MUSIC_ON %d", &music_on);
	fclose(fsetup);

    //color_depth = 16;
	color_depth = gdepth;
	set_color_depth(color_depth);

	switch(gmode)
	{
	case 0: rgfx = GFX_AUTODETECT;
			break;
	case 1: rgfx = GFX_SAFE;
			break;
/*	case 2: rgfx = GFX_DIRECTX;
			break;
	case 3: rgfx = GFX_DIRECTX_ACCEL;
			break;
	case 4: rgfx = GFX_DIRECTX_SOFT;
			break;
	case 5: rgfx = GFX_DIRECTX_SAFE;
			break;
	case 6: rgfx = GFX_DIRECTX_WIN;
			break;
	case 7: rgfx = GFX_DIRECTX_OVL;
			break;
	case 8: rgfx = GFX_GDI;
			break;
*/
	default: rgfx = GFX_AUTODETECT;
			 break;
	}


	if (set_gfx_mode (rgfx, 640, 480, 0, 0) < 0)
	{
		if (color_depth==15)
		{
			set_color_depth(16);
			if(set_gfx_mode (rgfx, 640, 480, 0, 0) < 0)
			{
				critical_error ("Unable to set graphics mode: %s", allegro_error);
			}
		} else
			critical_error ("Unable to set graphics mode: %s", allegro_error);
	}


    //FIXME: vymenit depth, nyni 15 primarni
/*
	if (set_gfx_mode (GFX_DIRECTX_ACCEL, 640, 480, 0, 0) < 0) {
		rest(1000);
        color_depth = 15;
		set_color_depth(color_depth);
		if (set_gfx_mode (GFX_DIRECTX_ACCEL, 640, 480, 0, 0) < 0)
			critical_error ("Unable to set graphics mode: %s", allegro_error);
		}
*/
	set_palette (desktop_palette);


	/* Create the screen buffer bitmap */
#ifdef TO_VIDEO
    na_nic = create_video_bitmap (SCREEN_W, SCREEN_H);
	//na_nic = create_video_bitmap (640, 200);
	game_screen = create_video_bitmap (SCREEN_W, SCREEN_H);
	if (!game_screen)
		game_screen = create_bitmap (SCREEN_W, SCREEN_H);
    game_screen2 = create_video_bitmap (SCREEN_W, SCREEN_H);
	if (!game_screen)
		game_screen2 = create_bitmap (SCREEN_W, SCREEN_H);

#else
	game_screen = create_bitmap(SCREEN_W, SCREEN_H);
    game_screen2 = create_bitmap(SCREEN_W, SCREEN_H);

#endif
	if (!game_screen)
		critical_error ("Unable to create game_screen bitmap");

#ifdef TO_VIDEO
    acquire_bitmap(game_screen);
#endif
    set_clip(game_screen, 0, 0, 639, 479);
	clear(game_screen);
#ifdef TO_VIDEO
    release_bitmap(game_screen);
#endif

	textout(screen, font, "LOADING..", 40, SCREEN_H - 40, makecol(255, 255, 255));
	tovy_delay(40);

	mouse_pointer = load_bitmap("data/gfx/c_hand.bmp", pal);
	//mouse_pointer2 = load_bitmap("data/gfx/c_head.bmp", pal);
	mouse_pointer2 = load_bitmap("data/gfx/c_hand1.bmp", pal);
	mouse_shot = load_bitmap("data/gfx/cursor1.bmp", pal);
	//mouse_shot = load_bitmap("data/gfx/kurzor.pcx", pal);
	set_mouse_sprite(mouse_pointer);
	//FIXME: na co je focus?
	set_mouse_sprite_focus(32, 32);
	//set_mouse_range(20, 20, 640 - 20, 340);
	set_mouse_range(20, 20, 640 - 20, 480-20);
	//set_mouse_speed(int xspeed, int yspeed);
	//set_mouse_speed(2, 2);



	init_all();
	comix_play("intro.cmx");




	menu_main();



	/* Make sure it all gets copied to the screen immediately */
	//full_redraw = 1;

	/* Arrange to be notified if we lose the screen bitmap's contents */
	//install_lost_bitmap_callback (lost_bitmap_callback_routine);


    //COMIX
    //comix_play("intro.cmx");


	//main_game();
	tovy_delay(8);
	comix_play("goodbye.cmx");

    destroy_all();
/*
#ifdef TO_VIDEO
    acquire_bitmap(game_screen);
	acquire_bitmap(game_screen2);
	acquire_bitmap(na_nic);
#endif
	*/
//	destroy_bitmap(na_nic);
/*
#ifdef TO_VIDEO
    release_bitmap(game_screen);
	release_bitmap(game_screen2);
	release_bitmap(game_screen3);
#endif
	*/

	//set_gfx_mode (GFX_TEXT, 0, 0, 0, 0);
	//allegro_message("Thanks for playing!\n");

	/* Tidy up before exiting */

	allegro_exit();

#ifdef DEBUG_VERSION
    fprintf(debugfile, "Program done.\n");
    fclose(debugfile);
#endif

}
